      MODULE mod_iceshelfvar
!
!svn $Id$
!================================================== Hernan G. Arango ===
! Copyright (c) 2002-2013 The ROMS/TOMS Group  Benjamin K. Galton-Fenzi!
!    Licensed under a MIT/X style license                              !
!    See License_ROMS.txt                                              !
!=======================================================================
!                                                                      !
!  Ice Shelf Model Kernel Variables:                                   !
!                                                                      !
      USE mod_kinds
!
      implicit none
!
      TYPE T_ICESHELFVAR
!
!  Nonlinear model state.
!
        real(r8), pointer :: gammaT(:,:)
        real(r8), pointer :: gammaS(:,:)
        real(r8), pointer :: Tb(:,:)
        real(r8), pointer :: Tstar(:,:)
        real(r8), pointer :: ustar(:,:)
        real(r8), pointer :: Sb(:,:)
        real(r8), pointer :: m(:,:)
        real(r8), pointer :: ssflxSOF(:,:)
        real(r8), pointer :: shflxSOF(:,:)
      END TYPE T_ICESHELFVAR
      TYPE (T_ICESHELFVAR), allocatable :: ICESHELFVAR(:)
      CONTAINS
      SUBROUTINE allocate_iceshelfvar (ng, LBi, UBi, LBj, UBj)
!
!=======================================================================
!                                                                      !
!  This routine allocates all variables in the module for all nested   !
!  grids.                                                              !
!                                                                      !
!=======================================================================
!
      USE mod_param
      USE mod_ncparam
      USE mod_iceshelf
!
!  Imported variable declarations.
!
      integer, intent(in) :: ng, LBi, UBi, LBj, UBj
!
!-----------------------------------------------------------------------
!  Allocate structure variables.
!-----------------------------------------------------------------------
!
      IF (ng.eq.1) allocate ( ICESHELFVAR(Ngrids) )
!
!  Nonlinear model state.
!
      allocate ( ICESHELFVAR(ng) % gammaT(LBi:UBi,LBj:UBj) )
      allocate ( ICESHELFVAR(ng) % gammaS(LBi:UBi,LBj:UBj) )
      allocate ( ICESHELFVAR(ng) % Tb(LBi:UBi,LBj:UBj) )
      allocate ( ICESHELFVAR(ng) % Tstar(LBi:UBi,LBj:UBj) )
      allocate ( ICESHELFVAR(ng) % ustar(LBi:UBi,LBj:UBj) )
      allocate ( ICESHELFVAR(ng) % Sb(LBi:UBi,LBj:UBj) )
      allocate ( ICESHELFVAR(ng) % m(LBi:UBi,LBj:UBj) )
      allocate ( ICESHELFVAR(ng) % ssflxSOF(LBi:UBi,LBj:UBj) )
      allocate ( ICESHELFVAR(ng) % shflxSOF(LBi:UBi,LBj:UBj) )
      RETURN
      END SUBROUTINE allocate_iceshelfvar
      SUBROUTINE initialize_iceshelfvar (ng, tile, model)
!
!=======================================================================
!                                                                      !
!  This routine initialize structure variables in the module using     !
!  first touch distribution policy. In shared-memory configuration,    !
!  this operation actually performs the propagation of the "shared     !
!  arrays" across the cluster,  unless another policy is specified     !
!  to  override the default.                                           !
!                                                                      !
!=======================================================================
!
      USE mod_param
      USE mod_ncparam
      USE mod_iceshelf
!
!  Imported variable declarations.
!
      integer, intent(in) :: ng, tile, model
!
!  Local variable declarations.
!
      integer :: Imin, Imax, Jmin, Jmax
      integer :: i, itrc, j, k
      real(r8), parameter :: IniVal = 0.0_r8
!
!-----------------------------------------------------------------------
!  Set lower and upper tile bounds and staggered variables bounds for
!  this horizontal domain partition.  Notice that if tile=-1, it will
!  set the values for the global grid.
!-----------------------------------------------------------------------
!
      integer :: Istr, IstrB, IstrP, IstrR, IstrT, IstrM, IstrU
      integer :: Iend, IendB, IendP, IendR, IendT
      integer :: Jstr, JstrB, JstrP, JstrR, JstrT, JstrM, JstrV
      integer :: Jend, JendB, JendP, JendR, JendT
      integer :: Istrm3, Istrm2, Istrm1, IstrUm2, IstrUm1
      integer :: Iendp1, Iendp2, Iendp2i, Iendp3
      integer :: Jstrm3, Jstrm2, Jstrm1, JstrVm2, JstrVm1
      integer :: Jendp1, Jendp2, Jendp2i, Jendp3
!
      Istr   =BOUNDS(ng) % Istr   (tile)
      IstrB  =BOUNDS(ng) % IstrB  (tile)
      IstrM  =BOUNDS(ng) % IstrM  (tile)
      IstrP  =BOUNDS(ng) % IstrP  (tile)
      IstrR  =BOUNDS(ng) % IstrR  (tile)
      IstrT  =BOUNDS(ng) % IstrT  (tile)
      IstrU  =BOUNDS(ng) % IstrU  (tile)
      Iend   =BOUNDS(ng) % Iend   (tile)
      IendB  =BOUNDS(ng) % IendB  (tile)
      IendP  =BOUNDS(ng) % IendP  (tile)
      IendR  =BOUNDS(ng) % IendR  (tile)
      IendT  =BOUNDS(ng) % IendT  (tile)
      Jstr   =BOUNDS(ng) % Jstr   (tile)
      JstrB  =BOUNDS(ng) % JstrB  (tile)
      JstrM  =BOUNDS(ng) % JstrM  (tile)
      JstrP  =BOUNDS(ng) % JstrP  (tile)
      JstrR  =BOUNDS(ng) % JstrR  (tile)
      JstrT  =BOUNDS(ng) % JstrT  (tile)
      JstrV  =BOUNDS(ng) % JstrV  (tile)
      Jend   =BOUNDS(ng) % Jend   (tile)
      JendB  =BOUNDS(ng) % JendB  (tile)
      JendP  =BOUNDS(ng) % JendP  (tile)
      JendR  =BOUNDS(ng) % JendR  (tile)
      JendT  =BOUNDS(ng) % JendT  (tile)
!
      Istrm3 =BOUNDS(ng) % Istrm3 (tile)            ! Istr-3
      Istrm2 =BOUNDS(ng) % Istrm2 (tile)            ! Istr-2
      Istrm1 =BOUNDS(ng) % Istrm1 (tile)            ! Istr-1
      IstrUm2=BOUNDS(ng) % IstrUm2(tile)            ! IstrU-2
      IstrUm1=BOUNDS(ng) % IstrUm1(tile)            ! IstrU-1
      Iendp1 =BOUNDS(ng) % Iendp1 (tile)            ! Iend+1
      Iendp2 =BOUNDS(ng) % Iendp2 (tile)            ! Iend+2
      Iendp2i=BOUNDS(ng) % Iendp2i(tile)            ! Iend+2 interior
      Iendp3 =BOUNDS(ng) % Iendp3 (tile)            ! Iend+3
      Jstrm3 =BOUNDS(ng) % Jstrm3 (tile)            ! Jstr-3
      Jstrm2 =BOUNDS(ng) % Jstrm2 (tile)            ! Jstr-2
      Jstrm1 =BOUNDS(ng) % Jstrm1 (tile)            ! Jstr-1
      JstrVm2=BOUNDS(ng) % JstrVm2(tile)            ! JstrV-2
      JstrVm1=BOUNDS(ng) % JstrVm1(tile)            ! JstrV-1
      Jendp1 =BOUNDS(ng) % Jendp1 (tile)            ! Jend+1
      Jendp2 =BOUNDS(ng) % Jendp2 (tile)            ! Jend+2
      Jendp2i=BOUNDS(ng) % Jendp2i(tile)            ! Jend+2 interior
      Jendp3 =BOUNDS(ng) % Jendp3 (tile)            ! Jend+3
!
!  Set array initialization range.
!
      Imin=BOUNDS(ng)%LBi(tile)
      Imax=BOUNDS(ng)%UBi(tile)
      Jmin=BOUNDS(ng)%LBj(tile)
      Jmax=BOUNDS(ng)%UBj(tile)
!
!-----------------------------------------------------------------------
!  Initialize iceshelf structure variables.
!-----------------------------------------------------------------------
!
!  Nonlinear model state.
!
      IF ((model.eq.0).or.(model.eq.iNLM)) THEN
        DO j=Jmin,Jmax
          DO i=Imin,Imax
            ICESHELFVAR(ng) % gammaT(i,j) = IniVal
            ICESHELFVAR(ng) % gammaS(i,j) = IniVal
            ICESHELFVAR(ng) % Tb(i,j) = IniVal
            ICESHELFVAR(ng) % Tstar(i,j) = IniVal
            ICESHELFVAR(ng) % ustar(i,j) = IniVal
            ICESHELFVAR(ng) % Sb(i,j) = IniVal
            ICESHELFVAR(ng) % m(i,j) = IniVal
            ICESHELFVAR(ng) % ssflxSOF(i,j) = IniVal
            ICESHELFVAR(ng) % shflxSOF(i,j) = IniVal
          END DO
        END DO
      END IF
      RETURN
      END SUBROUTINE initialize_iceshelfvar
      END MODULE mod_iceshelfvar
